<!--
/**
 * Calendar
 * @param   calendarId			"Calendar_1"
 * @param   selectedDate		"2009-09-05"
 * @param   beginYear           1960
 * @param   endYear             2020
 * @param   language            0(zh_cn)|1(en_us)|2(en_en)|3(zh_tw)|4(jp)
 * @param   patternDelimiter    "-"
 * @param   date2StringPattern  "yyyy-MM-dd"
 * @param   string2DatePattern  "ymd"
 * @version V20090104
 * @author  KimSoft (jinqinghua [at] gmail.com)
 * NOTE!    you can use it free, but keep the copyright please
 * IMPORTANT:you must include this script file inner html body element 
 * @see http://code.google.com/p/kimsoft-jscalendar/
 * @modified by EASYNTH (www.easynth.com)
 */
function Calendar(calendarId, selectedDate, beginYear, endYear, language, patternDelimiter, date2StringPattern, string2DatePattern) {
	this.calendarId = calendarId;
	this.beginYear = beginYear || 1960;
	this.endYear   = endYear   || 2020;
	this.language  = language  || 1;
	this.patternDelimiter = patternDelimiter     || "-";
	this.date2StringPattern = date2StringPattern || Calendar.language["date2StringPattern"][this.language].replace(/\-/g, this.patternDelimiter);
	this.string2DatePattern = string2DatePattern || Calendar.language["string2DatePattern"][this.language];
	
	this.dateControl = null;
	this.panel = this.getElementById(calendarId);
	this.mini_mode = (parseInt(this.panel.style.width) < 200) || (parseInt(this.panel.style.height) < 200);
	this.form = null;
	
	var dateParts = selectedDate.split(this.patternDelimiter);
	this.date = new Date(dateParts[0], dateParts[1] - 1, dateParts[2]);
	this.year = this.date.getFullYear();
	this.month = this.date.getMonth();
};

Calendar.language = {
	"year"   : ["\u5e74", "", "", "\u5e74","\u5e74"],
	"months" : [
				["\u4e00\u6708","\u4e8c\u6708","\u4e09\u6708","\u56db\u6708","\u4e94\u6708","\u516d\u6708","\u4e03\u6708","\u516b\u6708","\u4e5d\u6708","\u5341\u6708","\u5341\u4e00\u6708","\u5341\u4e8c\u6708"],
				["JAN","FEB","MAR","APR","MAY","JUN","JUL","AUG","SEP","OCT","NOV","DEC"],
				["JAN","FEB","MAR","APR","MAY","JUN","JUL","AUG","SEP","OCT","NOV","DEC"],
				["\u4e00\u6708","\u4e8c\u6708","\u4e09\u6708","\u56db\u6708","\u4e94\u6708","\u516d\u6708","\u4e03\u6708","\u516b\u6708","\u4e5d\u6708","\u5341\u6708","\u5341\u4e00\u6708","\u5341\u4e8c\u6708"],
				["\u4e00\u6708","\u4e8c\u6708","\u4e09\u6708","\u56db\u6708","\u4e94\u6708","\u516d\u6708","\u4e03\u6708","\u516b\u6708","\u4e5d\u6708","\u5341\u6708","\u5341\u4e00\u6708","\u5341\u4e8c\u6708"]				
				],
	"months_mini" : [
				["1","2","3","4","5","6","7","8","9","10","11","12"],
				["1","2","3","4","5","6","7","8","9","10","11","12"],
				["1","2","3","4","5","6","7","8","9","10","11","12"],
				["1","2","3","4","5","6","7","8","9","10","11","12"],
				["1","2","3","4","5","6","7","8","9","10","11","12"]			
				],
	"weeks"  : [["\u65e5","\u4e00","\u4e8c","\u4e09","\u56db","\u4e94","\u516d"],
				["Sun","Mon","Tur","Wed","Thu","Fri","Sat"],
				["Sun","Mon","Tur","Wed","Thu","Fri","Sat"],
				["\u65e5","\u4e00","\u4e8c","\u4e09","\u56db","\u4e94","\u516d"],
				["\u65e5","\u6708","\u706b","\u6c34","\u6728","\u91d1","\u571f"],
			],
	"weeks_mini"  : [["\u65e5","\u4e00","\u4e8c","\u4e09","\u56db","\u4e94","\u516d"],
				["S","M","T","W","T","F","S"],
				["S","M","T","W","T","F","S"],
				["\u65e5","\u4e00","\u4e8c","\u4e09","\u56db","\u4e94","\u516d"],
				["\u65e5","\u6708","\u706b","\u6c34","\u6728","\u91d1","\u571f"],
			],
	"date2StringPattern" : ["yyyy-MM-dd", "yyyy-MM-dd", "yyyy-MM-dd", "yyyy-MM-dd", "yyyy-MM-dd"],
	"string2DatePattern" : ["ymd","ymd", "ymd", "ymd", "ymd"]
};

Calendar.prototype.draw = function() {
	calendar = this;
	var _cs = [];
	_cs[_cs.length] = '<table id="' + this.calendarId + '_Table" class="'+this.calendarId+'_table" width="100%" height="100%" border="0" cellpadding="1" cellspacing="1" align="center" style="background-color:transparent;">';
	_cs[_cs.length] = ' <tr height=20>';
	_cs[_cs.length] = '  <th class="'+this.calendarId+'_th" colspan=7>';
	_cs[_cs.length] = '   <form id="' + this.calendarId + '_Form" name="' + this.calendarId + '_Form" method="post" class="'+this.calendarId+'_form">';
	_cs[_cs.length] = '    <table width=100% border=0 cellspacing=0 cellpadding=0 class="'+this.calendarId+'_table">';
	_cs[_cs.length] = '     <tr>';
	_cs[_cs.length] = '      <th class="'+this.calendarId+'_th"><input onfocus="blur()" class="'+this.calendarId+'_l" name="goPrevMonthButton" type="button" id="goPrevMonthButton" value="&lt;" \/><\/th>';
	_cs[_cs.length] = '      <th class="'+this.calendarId+'_th" colspan="5"><nobr><select class="'+this.calendarId+'_year" name="yearSelect" id="yearSelect"><\/select> <select class="'+this.calendarId+'_month" name="monthSelect" id="monthSelect"><\/select><nobr><\/th>';
	_cs[_cs.length] = '      <th class="'+this.calendarId+'_th"><input onfocus="blur()" class="'+this.calendarId+'_r" name="goNextMonthButton" type="button" id="goNextMonthButton" value="&gt;" \/><\/th>';
	_cs[_cs.length] = '     <\/tr>';
	_cs[_cs.length] = '    <\/table>';
	_cs[_cs.length] = '   <\/form>';
	_cs[_cs.length] = '  <\/th>';
	_cs[_cs.length] = ' <\/tr>';
	_cs[_cs.length] = ' <tr>';
	for(var i = 0; i < 7; i++) {
		if (i == 0) {
			_cs[_cs.length] = '<th class="'+this.calendarId+'_theader">';
		} else {
			_cs[_cs.length] = '<th class="'+this.calendarId+'_theader" width="14.3%">';
		}
		if (calendar.mini_mode == true) {
			_cs[_cs.length] = Calendar.language["weeks_mini"][this.language][i];
		} else {
			_cs[_cs.length] = Calendar.language["weeks"][this.language][i];
		}
		_cs[_cs.length] = '<\/th>';	
	}
	_cs[_cs.length] = '<\/tr>';
	for(var i = 0; i < 6; i++){
		_cs[_cs.length] = '<tr align="center">';
		for(var j = 0; j < 7; j++) {
			switch (j) {
				case 0: _cs[_cs.length] = '<td class="'+this.calendarId+'_sun '+this.calendarId+'_button_normal">&nbsp;<\/td>'; break;
				case 6: _cs[_cs.length] = '<td class="'+this.calendarId+'_sat '+this.calendarId+'_button_normal">&nbsp;<\/td>'; break;
				default:_cs[_cs.length] = '<td class="'+this.calendarId+'_normal '+this.calendarId+'_button_normal">&nbsp;<\/td>'; break;
			}
		}
		_cs[_cs.length] = '<\/tr>';
	}
	_cs[_cs.length] = '<\/table>';
	this.panel.innerHTML = _cs.join("");
	this.form = document.forms[this.calendarId + "_Form"];

	var calendar = this;
	this.form.goPrevMonthButton.onclick = function () {calendar.goPrevMonth(this);}
	this.form.goNextMonthButton.onclick = function () {calendar.goNextMonth(this);}
	this.form.yearSelect.onchange = function () {calendar.update(this);}
	this.form.monthSelect.onchange = function () {calendar.update(this);}
};

Calendar.prototype.selectToday = function() {
	calendar = this;
	var today = new Date();
	calendar.date = today;
	calendar.year = today.getFullYear();
	calendar.month = today.getMonth();
	if (calendar.dateControl) {
		calendar.dateControl.value = today.format(calendar.date2StringPattern);
	}
}

Calendar.prototype.bindYear = function() {
	var ys = this.form.yearSelect;
	ys.length = 0;
	for (var i = this.beginYear; i <= this.endYear; i++){
		ys.options[ys.length] = new Option(i + Calendar.language["year"][this.language], i);
	}
};

Calendar.prototype.bindMonth = function() {
	var ms = this.form.monthSelect;
	ms.length = 0;
	for (var i = 0; i < 12; i++){
		if (this.mini_mode == true) {
			ms.options[ms.length] = new Option(Calendar.language["months_mini"][this.language][i], i);
		} else {
			ms.options[ms.length] = new Option(Calendar.language["months"][this.language][i], i);
		}
	}
};

Calendar.prototype.resetAllCellBgColors = function() {
	// reset all td background color
	var tds = this.getElementsByTagName("td", this.getElementById(this.calendarId + "_Table", document));
	for(var k = 0; k < tds.length; k++) {
		var pf = this.calendarId + "_normal ";
		if ((k % 7) == 0) {
			pf = this.calendarId + "_sun ";
		} else if ((k % 7) == 6) {
			pf = this.calendarId + "_sat ";
		}
		tds[k].outClass = pf + this.calendarId + "_button_normal";
		tds[k].className = tds[k].outClass;
		tds[k].onmouseover = function () {this.className = this.overClass;}
		tds[k].onmouseout  = function () {this.className = this.outClass;}
  	}
}

Calendar.prototype.goPrevMonth = function(e){
	if (this.year == this.beginYear && this.month == 0){return;}
	this.month--;
	if (this.month == -1) {
		this.year--;
		this.month = 11;
	}
	this.date = new Date(this.year, this.month, 1);
	this.resetAllCellBgColors();
	this.changeSelect();
	this.bindData();
};

Calendar.prototype.goNextMonth = function(e){
	if (this.year == this.endYear && this.month == 11){return;}
	this.month++;
	if (this.month == 12) {
		this.year++;
		this.month = 0;
	}
	this.date = new Date(this.year, this.month, 1);
	this.resetAllCellBgColors();
	this.changeSelect();
	this.bindData();
};

Calendar.prototype.changeSelect = function() {
	var ys = this.form.yearSelect;
	var ms = this.form.monthSelect;
	for (var i= 0; i < ys.length; i++){
		if (ys.options[i].value == this.date.getFullYear()){
			ys[i].selected = true;
			break;
		}
	}
	for (var i= 0; i < ms.length; i++){
		if (ms.options[i].value == this.date.getMonth()){
			ms[i].selected = true;
			break;
		}
	}
};

Calendar.prototype.update = function (e){
	this.year  = e.form.yearSelect.options[e.form.yearSelect.selectedIndex].value;
	this.month = e.form.monthSelect.options[e.form.monthSelect.selectedIndex].value;
	this.date = new Date(this.year, this.month, 1);
	this.resetAllCellBgColors();
	this.changeSelect();
	this.bindData();
};

Calendar.prototype.bindData = function () {
	var calendar = this;
	var dateArray = this.getMonthViewDateArray(this.date.getFullYear(), this.date.getMonth());
	var tds = this.getElementsByTagName("td", this.getElementById(this.calendarId + "_Table", document));
	
	for(var i = 0; i < tds.length; i++) {
		var today = calendar.date;
		tds[i].onclick = null;
		tds[i].onmouseover = null;
		tds[i].onmouseout = null;
		tds[i].innerHTML = dateArray[i] || "&nbsp;";
		if (i > dateArray.length - 1) continue;
		if (dateArray[i]){
			var prefix = this.calendarId + "_normal ";
			if ((i % 7) == 0) {
				prefix = this.calendarId + "_sun ";
			} else if ((i % 7) == 6) {
				prefix = this.calendarId + "_sat ";
			}
			tds[i].overClass = prefix + this.calendarId + "_button_hover";
			tds[i].outClass = prefix + this.calendarId + "_button_normal";
			tds[i].className = tds[i].outClass;
			tds[i].onclick = function () {
				// set current date
				calendar.date = new Date(calendar.date.getFullYear(), calendar.date.getMonth(), this.innerHTML);
				calendar.year = today.getFullYear();
				calendar.month = today.getMonth();
				if (calendar.dateControl) {
					calendar.dateControl.value = calendar.date.format(calendar.date2StringPattern);
				}
				// reset all td background color
				calendar.resetAllCellBgColors();
  				var oldPrefix = this.className.split(" ")[0] + " ";
				this.outClass = oldPrefix + calendar.calendarId + "_button_selected";
				this.className = this.outClass;
				this.onmouseover = function () {this.className = this.overClass;}
				this.onmouseout  = function () {this.className = this.outClass;}
				// date changed event handler
				try {
					eval(calendar.calendarId + "_onCalendarDateChanged();");
				} catch(err) {}
			}
			tds[i].onmouseover = function () {this.className = this.overClass;}
			tds[i].onmouseout  = function () {this.className = this.outClass;}
			
			if (today.getFullYear() == calendar.date.getFullYear()) {
				if (today.getMonth() == calendar.date.getMonth()) {
					if (today.getDate() == dateArray[i]) {
						tds[i].outClass = prefix + this.calendarId + "_button_selected";
						tds[i].className = tds[i].outClass;
						tds[i].onmouseover = function () {this.className = prefix + calendar.calendarId + "_button_hover";}
						tds[i].onmouseout  = function () {this.className = prefix + calendar.calendarId + "_button_selected";}
					}
				}
			}
		}//end if
	}//end for
};

Calendar.prototype.getMonthViewDateArray = function (y, m) {
	var dateArray = new Array(42);
	var dayOfFirstDate = new Date(y, m, 1).getDay();
	var dateCountOfMonth = new Date(y, m + 1, 0).getDate();
	for (var i = 0; i < dateCountOfMonth; i++) {
		dateArray[i + dayOfFirstDate] = i + 1;
	}
	return dateArray;
};

Calendar.prototype.init = function (dateControl, popuControl) {
	this.dateControl = dateControl || null;
	popuControl = popuControl || dateControl;
	this.draw();
	this.bindYear();
	this.bindMonth();
	if (dateControl && dateControl.value.length > 0){
		this.date  = new Date(dateControl.value.toDate(this.patternDelimiter, this.string2DatePattern));
		this.year  = this.date.getFullYear();
		this.month = this.date.getMonth();
	}
	this.changeSelect();
	this.bindData();
	if (popuControl) {
		var xy = this.getAbsPoint(popuControl);
		this.panel.style.left = xy.x + "px";
		this.panel.style.top = (xy.y + dateControl.offsetHeight) + "px";
	}
};

Calendar.prototype.hide = function() {
	this.panel.style.display = "none";
};

Calendar.prototype.getElementById = function(id, object){
	object = object || document;
	return document.getElementById ? object.getElementById(id) : document.all(id);
};

Calendar.prototype.getElementsByTagName = function(tagName, object){
	object = object || document;
	return document.getElementsByTagName ? object.getElementsByTagName(tagName) : document.all.tags(tagName);
};

Calendar.prototype.getAbsPoint = function (e){
	var x = e.offsetLeft;
	var y = e.offsetTop;
	while(e = e.offsetParent){
		x += e.offsetLeft;
		y += e.offsetTop;
	}
	return {"x": x, "y": y};
};

/**
 * @param   d the delimiter
 * @param   p the pattern of your date
 * @author  meizz
 * @author  kimsoft add w+ pattern
 */
Date.prototype.format = function(style) {
	var o = {
		"M+" : this.getMonth() + 1, //month
		"d+" : this.getDate(),      //day
		"h+" : this.getHours(),     //hour
		"m+" : this.getMinutes(),   //minute
		"s+" : this.getSeconds(),   //second
		"w+" : "\u65e5\u4e00\u4e8c\u4e09\u56db\u4e94\u516d".charAt(this.getDay()),   //week
		"q+" : Math.floor((this.getMonth() + 3) / 3),  //quarter
		"S"  : this.getMilliseconds() //millisecond
	}
	if (/(y+)/.test(style)) {
		style = style.replace(RegExp.$1, (this.getFullYear() + "").substr(4 - RegExp.$1.length));
	}
	for(var k in o){
		if (new RegExp("("+ k +")").test(style)){
			style = style.replace(RegExp.$1, RegExp.$1.length == 1 ? o[k] : ("00" + o[k]).substr(("" + o[k]).length));
		}
	}
	return style;
};

/**
 * @param d the delimiter
 * @param p the pattern of your date
 * @rebuilder kimsoft
 * @version build 2006.12.15
 */
String.prototype.toDate = function(delimiter, pattern) {
	delimiter = delimiter || "-";
	pattern = pattern || "ymd";
	var a = this.split(delimiter);
	if (a.length != 3) throw new Error("Incorrect Format");
	var y = parseInt(a[pattern.indexOf("y")], 10);
	if(isNaN(y)) throw new Error("Year Not Found");
	if(y.toString().length <= 2) y += 2000;
	var m = parseInt(a[pattern.indexOf("m")], 10) - 1;
	if(isNaN(m)) throw new Error("Month Not Found");
	var d = parseInt(a[pattern.indexOf("d")], 10);
	if(isNaN(d)) throw new Error("Day Not Found");
	return new Date(y, m, d);
};

// Some export functions
function Calendar_getDateString(id) {
	var calendarWrapper = document.getElementById(id);
	if (calendarWrapper != null) {
		var calendar = calendarWrapper.wrappedObj;
		return calendar.date.format(calendar.date2StringPattern);
	} else {
		return "";
	}
}

function Calendar_getYear(id) {
	var calendarWrapper = document.getElementById(id);
	if (calendarWrapper != null) {
		var calendar = calendarWrapper.wrappedObj;
		return calendar.date.getFullYear();
	} else {
		return "";
	}
}

function Calendar_getMonth(id) {
	var calendarWrapper = document.getElementById(id);
	if (calendarWrapper != null) {
		var calendar = calendarWrapper.wrappedObj;
		return calendar.date.getMonth() + 1;
	} else {
		return "";
	}
}

function Calendar_getDay(id) {
	var calendarWrapper = document.getElementById(id);
	if (calendarWrapper != null) {
		var calendar = calendarWrapper.wrappedObj;
		return calendar.date.getDate();
	} else {
		return "";
	}
}

function Calendar_setDateString(id, value) {
	var calendarWrapper = document.getElementById(id);
	if (calendarWrapper != null) {
		var calendar = calendarWrapper.wrappedObj;
		var newDate = new Date();
		try {
			newDate = value.toDate(calendar.patternDelimiter, calendar.string2DatePattern);
		} catch (err) {}
		calendar.date = newDate;
		calendar.year = newDate.getFullYear();
		calendar.month = newDate.getMonth();
		calendar.resetAllCellBgColors();
		calendar.changeSelect();
		calendar.bindData();
	}
}

function Calendar_fireDateChangedEvent(id) {
	var calendarWrapper = document.getElementById(id);
	if (calendarWrapper != null) {
		var calendar = calendarWrapper.wrappedObj;
		try {
			eval(calendar.calendarId + "_onCalendarDateChanged();");
		} catch(err) {}
	}
}
//-->